Versions
========

0.0.2 (05.04.2020)
========
- Specify local debug section

0.0.2 (05.04.2020)
========
- Describe demo usage

0.0.1 (05.04.2020)
========
- Support colored user prompt
- Build project environment setup
- Include runtime.txt template file
- Fix code analyser linters
- Show tool usage
- Add 'disallow_subclassing_any' argument to mypy tool
- Introduce template folder
- Introduce package template metafiles
- Define 'pypans' package name
- Introduce initial version of a project